==> vala-0.3.5.tar.bz2: vala-0.3.5/ccode/valaccodemodifiers.c <==
/* valaccodemodifiers.vala
 *
 * Copyright (C) 2006-2008  Jürg Billeter, Raffaele Sandrini
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 *	Raffaele Sandrini <raffaele@sandrini.ch>
 */

#include <ccode/valaccodemodifiers.h>








GType vala_ccode_modifiers_get_type (void) {
	static GType vala_ccode_modifiers_type_id = 0;
	if (G_UNLIKELY (vala_ccode_modifiers_type_id == 0)) {
		static const GFlagsValue values[] = {{VALA_CCODE_MODIFIERS_NONE, "VALA_CCODE_MODIFIERS_NONE", "none"}, {VALA_CCODE_MODIFIERS_STATIC, "VALA_CCODE_MODIFIERS_STATIC", "static"}, {VALA_CCODE_MODIFIERS_REGISTER, "VALA_CCODE_MODIFIERS_REGISTER", "register"}, {VALA_CCODE_MODIFIERS_EXTERN, "VALA_CCODE_MODIFIERS_EXTERN", "extern"}, {VALA_CCODE_MODIFIERS_INLINE, "VALA_CCODE_MODIFIERS_INLINE", "inline"}, {VALA_CCODE_MODIFIERS_VOLATILE, "VALA_CCODE_MODIFIERS_VOLATILE", "volatile"}, {0, NULL, NULL}};
		vala_ccode_modifiers_type_id = g_flags_register_static ("ValaCCodeModifiers", values);
	}
	return vala_ccode_modifiers_type_id;
}

==> vala-0.7.5.tar.bz2: vala-0.7.5/ccode/valaccodemodifiers.c <==
/* valaccodemodifiers.vala
 *
 * Copyright (C) 2006-2008  Jürg Billeter, Raffaele Sandrini
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 *	Raffaele Sandrini <raffaele@sandrini.ch>
 */

#include <glib.h>
#include <glib-object.h>


#define VALA_TYPE_CCODE_MODIFIERS (vala_ccode_modifiers_get_type ())

typedef enum  {
	VALA_CCODE_MODIFIERS_NONE = 0,
	VALA_CCODE_MODIFIERS_STATIC = 1 << 0,
	VALA_CCODE_MODIFIERS_REGISTER = 1 << 1,
	VALA_CCODE_MODIFIERS_EXTERN = 1 << 2,
	VALA_CCODE_MODIFIERS_INLINE = 1 << 3,
	VALA_CCODE_MODIFIERS_VOLATILE = 1 << 4
} ValaCCodeModifiers;



GType vala_ccode_modifiers_get_type (void);




GType vala_ccode_modifiers_get_type (void) {
	static GType vala_ccode_modifiers_type_id = 0;
	if (G_UNLIKELY (vala_ccode_modifiers_type_id == 0)) {
		static const GFlagsValue values[] = {{VALA_CCODE_MODIFIERS_NONE, "VALA_CCODE_MODIFIERS_NONE", "none"}, {VALA_CCODE_MODIFIERS_STATIC, "VALA_CCODE_MODIFIERS_STATIC", "static"}, {VALA_CCODE_MODIFIERS_REGISTER, "VALA_CCODE_MODIFIERS_REGISTER", "register"}, {VALA_CCODE_MODIFIERS_EXTERN, "VALA_CCODE_MODIFIERS_EXTERN", "extern"}, {VALA_CCODE_MODIFIERS_INLINE, "VALA_CCODE_MODIFIERS_INLINE", "inline"}, {VALA_CCODE_MODIFIERS_VOLATILE, "VALA_CCODE_MODIFIERS_VOLATILE", "volatile"}, {0, NULL, NULL}};
		vala_ccode_modifiers_type_id = g_flags_register_static ("ValaCCodeModifiers", values);
	}
	return vala_ccode_modifiers_type_id;
}
